@@ -1,9 +1,17 @@
 import random
+import shutil
 import sys
 import time
 
+from rich.traceback import install
+
 from progress_table import ProgressTable
 
+shutil.get_terminal_size()
+
+install()
+
+
 # Define the columns at the beginning
 table = ProgressTable(
     columns=["step", "x", "x squared"],
@@ -24,11 +32,6 @@ table.add_column("x", width=3)
 table.add_column("x root", color="red")
 table.add_column("random average", color=["bright", "red"], aggregate="mean")
 
-for _ in range(20):
-    print()
-
-time.sleep(1)
-
 for step in range(10):
     x = random.randint(0, 200)
 
